using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Controls;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.PortalControls;


public partial class CMSWebParts_Custom_TeamFilterQuery : CMSAbstractQueryFilterControl
{
    /// <summary>
    /// Child control creation.
    /// </summary>
    protected override void OnInit(EventArgs e)
    {
        SetupControl();

        base.OnInit(e);
    }


    /// <summary>
    /// Pre render event.
    /// </summary>
    protected override void OnPreRender(EventArgs e)
    {
        // Set filter settings
        if (RequestHelper.IsPostBack())
        {
            SetFilter();
        }

        base.OnPreRender(e);
    }


    /// <summary>
    /// Setup the inner controls.
    /// </summary>
    private void SetupControl()
    {
        if (this.StopProcessing)
        {
            this.Visible = false;
        }
        else if (!RequestHelper.IsPostBack())
        {
            // Load teams options into filter drop-down list
            InitializeTeams();

            // Initialize sort direction drop-down list
            IntializeSort();
        }
    }


    /// <summary>
    /// Ensures sorting direction options are loaded within drop-down list as filter options.
    /// </summary>
    private void IntializeSort()
    {
        // Initialize options
        this.drpOrder.Items.Add(new ListItem("Away team - Ascending", "awayasc"));
        this.drpOrder.Items.Add(new ListItem("Away team - Descending", "awaydesc"));
        this.drpOrder.Items.Add(new ListItem("Game date - Ascending", "gameasc"));
        this.drpOrder.Items.Add(new ListItem("Game date - Descending", "gamedesc"));
    }


    /// <summary>
    /// Ensures all teams are loaded within drop-down list as filter options.
    /// </summary>
    private void InitializeTeams()
    {
        // Get administrator uder
        UserInfo admin = UserInfoProvider.GetUserInfo("administrator");
        if (admin != null)
        {
            // Get custom table provider
            CustomTableItemProvider ctip = new CustomTableItemProvider(admin);
            if (ctip != null)
            {
                // Get all teams
                DataSet teams = ctip.GetItems("customtable.team", null, "TeamName ASC");
                if (!DataHelper.DataSourceIsEmpty(teams))
                {
                    // Bind teams to drop-down list
                    this.drpTeam.DataSource = teams.Tables[0];
                    this.drpTeam.DataTextField = "TeamName";
                    this.drpTeam.DataValueField = "ItemID";

                    this.drpTeam.DataBind();

                    // Add default '(all)' value
                    this.drpTeam.Items.Insert(0, new ListItem("(all)", "##ALL##"));
                }
            }
        }
    }


    /// <summary>
    /// Generates WHERE condition based on current selection.
    /// </summary>
    private void SetFilter()
    {
        string where = null;

        // Generate WHERE condition based on team selected
        if (this.drpTeam.SelectedValue != null)
        {
            int teamId = ValidationHelper.GetInteger(this.drpTeam.SelectedValue, 0);
            if (teamId > 0)
            {
                where = "GameTeamID = " + teamId;
            }
        }

        // Include sort direction
        string order = null;
        if (this.drpOrder.SelectedValue != "")
        {
            switch (this.drpOrder.SelectedValue)
            {
                case "awayasc":
                    order = "GameAwayTeam ASC";
                    break;

                case "awaydesc":
                    order = "GameAwayTeam DESC";
                    break;

                case "gameasc":
                    order = "GameDate ASC";
                    break;

                case "gamedesc":
                    order = "GameDate DESC";
                    break;
            }
        }

        if (where != null)
        {
            // Set where condition
            this.WhereCondition = where;
        }
        if (order != "")
        {
            // Set orderBy condition
            this.OrderBy = order;
        }

        this.RaiseOnFilterChanged();
    }
}
